Class: IpApi::IpBlock

Inherits:
ApiModelBase show all
Defined in:
lib/pnap_ip_api/models/ip_block.rb

Overview

IP Block Details.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ IpBlock

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/pnap_ip_api/models/ip_block.rb', line 119

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IpApi::IpBlock` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IpApi::IpBlock`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'location')
    self.location = attributes[:'location']
  end

  if attributes.key?(:'cidr_block_size')
    self.cidr_block_size = attributes[:'cidr_block_size']
  end

  if attributes.key?(:'cidr')
    self.cidr = attributes[:'cidr']
  end

  if attributes.key?(:'ip_version')
    self.ip_version = attributes[:'ip_version']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'parent_ip_block_allocation_id')
    self.parent_ip_block_allocation_id = attributes[:'parent_ip_block_allocation_id']
  end

  if attributes.key?(:'assigned_resource_id')
    self.assigned_resource_id = attributes[:'assigned_resource_id']
  end

  if attributes.key?(:'assigned_resource_type')
    self.assigned_resource_type = attributes[:'assigned_resource_type']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'is_system_managed')
    self.is_system_managed = attributes[:'is_system_managed']
  end

  if attributes.key?(:'is_bring_your_own')
    self.is_bring_your_own = attributes[:'is_bring_your_own']
  end

  if attributes.key?(:'created_on')
    self.created_on = attributes[:'created_on']
  end
end

Instance Attribute Details

#assigned_resource_idObject

ID of the resource assigned to the IP Block.



41
42
43
# File 'lib/pnap_ip_api/models/ip_block.rb', line 41

def assigned_resource_id
  @assigned_resource_id
end

#assigned_resource_typeObject

Type of the resource assigned to the IP Block.



44
45
46
# File 'lib/pnap_ip_api/models/ip_block.rb', line 44

def assigned_resource_type
  @assigned_resource_type
end

#cidrObject

The IP Block in CIDR notation.



29
30
31
# File 'lib/pnap_ip_api/models/ip_block.rb', line 29

def cidr
  @cidr
end

#cidr_block_sizeObject

CIDR IP Block Size. Currently this field should be set to either ‘/31`, `/30`, `/29`, `/28`, `/27`, `/26`, `/25`, `/24`, `/23` or `/22`.



26
27
28
# File 'lib/pnap_ip_api/models/ip_block.rb', line 26

def cidr_block_size
  @cidr_block_size
end

#created_onObject

Date and time when the IP block was created.



59
60
61
# File 'lib/pnap_ip_api/models/ip_block.rb', line 59

def created_on
  @created_on
end

#descriptionObject

The description of the IP Block.



47
48
49
# File 'lib/pnap_ip_api/models/ip_block.rb', line 47

def description
  @description
end

#idObject

IP Block identifier.



20
21
22
# File 'lib/pnap_ip_api/models/ip_block.rb', line 20

def id
  @id
end

#ip_versionObject

The IP Version of the block.



32
33
34
# File 'lib/pnap_ip_api/models/ip_block.rb', line 32

def ip_version
  @ip_version
end

#is_bring_your_ownObject

True if the IP block is a ‘bring your own` block.



56
57
58
# File 'lib/pnap_ip_api/models/ip_block.rb', line 56

def is_bring_your_own
  @is_bring_your_own
end

#is_system_managedObject

True if the IP block is a ‘system managed` block.



53
54
55
# File 'lib/pnap_ip_api/models/ip_block.rb', line 53

def is_system_managed
  @is_system_managed
end

#locationObject

IP Block location ID. Currently this field should be set to ‘PHX`, `ASH`, `SGP`, `NLD`, `CHI` or `SEA`.



23
24
25
# File 'lib/pnap_ip_api/models/ip_block.rb', line 23

def location
  @location
end

#parent_ip_block_allocation_idObject

IP Block parent identifier. If present, this block is subnetted from the parent IP Block.



38
39
40
# File 'lib/pnap_ip_api/models/ip_block.rb', line 38

def parent_ip_block_allocation_id
  @parent_ip_block_allocation_id
end

#statusObject

The status of the IP Block. Can have one of the following values: ‘creating`, `subnetted`, `assigning` , `error assigning` , `assigned` , `unassigning` , `error unassigning` or `unassigned`.



35
36
37
# File 'lib/pnap_ip_api/models/ip_block.rb', line 35

def status
  @status
end

#tagsObject

The tags assigned if any.



50
51
52
# File 'lib/pnap_ip_api/models/ip_block.rb', line 50

def tags
  @tags
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



82
83
84
# File 'lib/pnap_ip_api/models/ip_block.rb', line 82

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



87
88
89
# File 'lib/pnap_ip_api/models/ip_block.rb', line 87

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/pnap_ip_api/models/ip_block.rb', line 62

def self.attribute_map
  {
    :'id' => :'id',
    :'location' => :'location',
    :'cidr_block_size' => :'cidrBlockSize',
    :'cidr' => :'cidr',
    :'ip_version' => :'ipVersion',
    :'status' => :'status',
    :'parent_ip_block_allocation_id' => :'parentIpBlockAllocationId',
    :'assigned_resource_id' => :'assignedResourceId',
    :'assigned_resource_type' => :'assignedResourceType',
    :'description' => :'description',
    :'tags' => :'tags',
    :'is_system_managed' => :'isSystemManaged',
    :'is_bring_your_own' => :'isBringYourOwn',
    :'created_on' => :'createdOn'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/pnap_ip_api/models/ip_block.rb', line 262

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



112
113
114
115
# File 'lib/pnap_ip_api/models/ip_block.rb', line 112

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/pnap_ip_api/models/ip_block.rb', line 92

def self.openapi_types
  {
    :'id' => :'String',
    :'location' => :'String',
    :'cidr_block_size' => :'String',
    :'cidr' => :'String',
    :'ip_version' => :'String',
    :'status' => :'String',
    :'parent_ip_block_allocation_id' => :'String',
    :'assigned_resource_id' => :'String',
    :'assigned_resource_type' => :'String',
    :'description' => :'String',
    :'tags' => :'Array<TagAssignment>',
    :'is_system_managed' => :'Boolean',
    :'is_bring_your_own' => :'Boolean',
    :'created_on' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/pnap_ip_api/models/ip_block.rb', line 228

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      location == o.location &&
      cidr_block_size == o.cidr_block_size &&
      cidr == o.cidr &&
      ip_version == o.ip_version &&
      status == o.status &&
      parent_ip_block_allocation_id == o.parent_ip_block_allocation_id &&
      assigned_resource_id == o.assigned_resource_id &&
      assigned_resource_type == o.assigned_resource_type &&
      description == o.description &&
      tags == o.tags &&
      is_system_managed == o.is_system_managed &&
      is_bring_your_own == o.is_bring_your_own &&
      created_on == o.created_on
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


249
250
251
# File 'lib/pnap_ip_api/models/ip_block.rb', line 249

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



255
256
257
# File 'lib/pnap_ip_api/models/ip_block.rb', line 255

def hash
  [id, location, cidr_block_size, cidr, ip_version, status, parent_ip_block_allocation_id, assigned_resource_id, assigned_resource_type, description, tags, is_system_managed, is_bring_your_own, created_on].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



194
195
196
197
198
199
200
201
202
# File 'lib/pnap_ip_api/models/ip_block.rb', line 194

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@description.nil? && @description.to_s.length > 250
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 250.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



284
285
286
287
288
289
290
291
292
293
294
295
296
# File 'lib/pnap_ip_api/models/ip_block.rb', line 284

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



206
207
208
209
210
# File 'lib/pnap_ip_api/models/ip_block.rb', line 206

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@description.nil? && @description.to_s.length > 250
  true
end