Class: IpApi::IpBlockCreate

Inherits:
ApiModelBase show all
Defined in:
lib/pnap_ip_api/models/ip_block_create.rb

Overview

IP Block Request.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ IpBlockCreate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/pnap_ip_api/models/ip_block_create.rb', line 74

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `IpApi::IpBlockCreate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `IpApi::IpBlockCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'location')
    self.location = attributes[:'location']
  else
    self.location = nil
  end

  if attributes.key?(:'cidr_block_size')
    self.cidr_block_size = attributes[:'cidr_block_size']
  else
    self.cidr_block_size = nil
  end

  if attributes.key?(:'ip_version')
    self.ip_version = attributes[:'ip_version']
  else
    self.ip_version = 'V4'
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end
end

Instance Attribute Details

#cidr_block_sizeObject

CIDR IP Block Size. V4 supported sizes: [‘/31`, `/30`, `/29` or `/28`]. V6 supported sizes: [`/64`]. For a larger Block Size contact support.



23
24
25
# File 'lib/pnap_ip_api/models/ip_block_create.rb', line 23

def cidr_block_size
  @cidr_block_size
end

#descriptionObject

The description of the IP Block.



29
30
31
# File 'lib/pnap_ip_api/models/ip_block_create.rb', line 29

def description
  @description
end

#ip_versionObject

IP Version. This field should be set to ‘V4` or `V6`



26
27
28
# File 'lib/pnap_ip_api/models/ip_block_create.rb', line 26

def ip_version
  @ip_version
end

#locationObject

IP Block location ID. Currently this field should be set to ‘PHX`, `ASH`, `SGP`, `NLD`, `CHI` or `SEA`.



20
21
22
# File 'lib/pnap_ip_api/models/ip_block_create.rb', line 20

def location
  @location
end

#tagsObject

Tags to set to the ip-block. To create a new tag or list all the existing tags that you can use, refer to [Tags API](developers.phoenixnap.com/docs/tags/1/overview).



32
33
34
# File 'lib/pnap_ip_api/models/ip_block_create.rb', line 32

def tags
  @tags
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



46
47
48
# File 'lib/pnap_ip_api/models/ip_block_create.rb', line 46

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/pnap_ip_api/models/ip_block_create.rb', line 51

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
# File 'lib/pnap_ip_api/models/ip_block_create.rb', line 35

def self.attribute_map
  {
    :'location' => :'location',
    :'cidr_block_size' => :'cidrBlockSize',
    :'ip_version' => :'ipVersion',
    :'description' => :'description',
    :'tags' => :'tags'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/pnap_ip_api/models/ip_block_create.rb', line 208

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



67
68
69
70
# File 'lib/pnap_ip_api/models/ip_block_create.rb', line 67

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
# File 'lib/pnap_ip_api/models/ip_block_create.rb', line 56

def self.openapi_types
  {
    :'location' => :'String',
    :'cidr_block_size' => :'String',
    :'ip_version' => :'String',
    :'description' => :'String',
    :'tags' => :'Array<TagAssignmentRequest>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



183
184
185
186
187
188
189
190
191
# File 'lib/pnap_ip_api/models/ip_block_create.rb', line 183

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      location == o.location &&
      cidr_block_size == o.cidr_block_size &&
      ip_version == o.ip_version &&
      description == o.description &&
      tags == o.tags
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


195
196
197
# File 'lib/pnap_ip_api/models/ip_block_create.rb', line 195

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



201
202
203
# File 'lib/pnap_ip_api/models/ip_block_create.rb', line 201

def hash
  [location, cidr_block_size, ip_version, description, tags].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/pnap_ip_api/models/ip_block_create.rb', line 119

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @location.nil?
    invalid_properties.push('invalid value for "location", location cannot be nil.')
  end

  if @cidr_block_size.nil?
    invalid_properties.push('invalid value for "cidr_block_size", cidr_block_size cannot be nil.')
  end

  if !@description.nil? && @description.to_s.length > 250
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 250.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/pnap_ip_api/models/ip_block_create.rb', line 230

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



139
140
141
142
143
144
145
# File 'lib/pnap_ip_api/models/ip_block_create.rb', line 139

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @location.nil?
  return false if @cidr_block_size.nil?
  return false if !@description.nil? && @description.to_s.length > 250
  true
end